@@ -6,62 +6,6 @@
 #include "time.h"
 #include "math.h"
 
-class Date {
-
-        int day;
-        int month;
-        int year;
-        time_t currentTime;
-        time_t gmttime;
-        struct tm * timeinfo;
-
-public:
-
-        Date() {
-                time(&currentTime);
-                timeinfo = localtime(&currentTime);
-                day = timeinfo->tm_mday;
-                month = timeinfo->tm_mon + 1;
-                year = timeinfo->tm_year + 1900;
-                currentTime = mktime(timeinfo);
-
-        }
-
-        Date(int y, int m, int d) {
-                time(&currentTime);
-                timeinfo = localtime(&currentTime);
-                timeinfo->tm_mday = d;
-                timeinfo->tm_mon = m - 1;
-                timeinfo->tm_year = y - 1900;
-                day = d;
-                month = m;
-                year = y;
-                currentTime = mktime(timeinfo);
-        }
-
-        int getDay() {
-                return day;
-        }
-
-        int getMonth() {
-                return month;
-        }
-
-        int getYear() {
-                return year;
-        }
-
-        time_t getTime() {
-                return currentTime;
-        }
-
-        float getTimeZone() {
-                tm* ptm = gmtime(&currentTime);
-                gmttime = mktime(ptm);
-                float diff = currentTime - gmttime;
-                return diff / 3600;
-        }
-};
 
 static QString timeNames[7];/* = {
  'Fajr',
@@ -107,16 +51,6 @@ int numIterations;// = 1;		// number of iterations needed to compute times
 
 
 CalculationMethod calculationMethod;
-        // convert a calendar date to julian date (second method)
-float PrayTime::calcJD(int year, int month, int day) {
-                float J1970 = 2440588.0;
-                Date date(year, month, day);
-                int ms = date.getTime(); // # of milliseconds since midnight Jan 1, 1970
-              //  cout << "ms="<<ms << endl;
-                float days = floor(ms / (1 * 60 * 60 * 24));
-              //  cout << "days="<<days<<endl;
-                return J1970 + days - 0.5;
-        }
 
         //---------------------- Trigonometric Functions -----------------------
 
@@ -256,7 +190,7 @@ float PrayTime::calcJD(int year, int month, int day) {
 
         // convert float hours to 24h format
         QString PrayTime::floatToTime24(float time) {
-                //if (isNaN(time)) return InvalidTime;
+                if (isnan(time)) return InvalidTime;
                 time = fixhour(time + 0.5 / 60); // add 0.5 minutes to round
                 double hours = floor(time);
                 double minutes = floor((time - hours) * 60);
@@ -266,7 +200,7 @@ float PrayTime::calcJD(int year, int month, int day) {
 
         // convert float hours to 12h format
         QString PrayTime::floatToTime12(float time, bool noSuffix) {
-                //if (isNaN(time)) return InvalidTime;
+                if (isnan(time)) return InvalidTime;
                 time = fixhour(time + 0.5 / 60); // add 0.5 minutes to round
                 int hours = (int) floor(time);
                 int minutes = (int) floor((time - hours) * 60);
@@ -331,8 +265,8 @@ float PrayTime::calcJD(int year, int month, int day) {
 
         // convert hours to day portions
         float * PrayTime::dayPortion(float times[]) {
-                for (int i = 0; i < 7; i++) {
-                        times[i] /= 24;
+                for (int i = 0; i < 7; i++) {    
+                    times[i] /= 24;
                 }
                 return times;
         }
@@ -364,6 +298,7 @@ float PrayTime::calcJD(int year, int month, int day) {
         // compute prayer times at given julian date
         void PrayTime::computeTimes(float times[]) {
                 float * t = dayPortion(times);
+
                 float Fajr = computeTime(180 - calculationMethod.getFajrAngle(), t[0]);
                 float Sunrise = computeTime(180 - 0.833, t[1]);
                 float Dhuhr = computeMidDay(t[2]);
@@ -378,6 +313,33 @@ float PrayTime::calcJD(int year, int month, int day) {
                 }
         }
 
+        // adjust Fajr, Isha and Maghrib for locations in higher latitudes
+        void PrayTime::adjustHighLatTimes(float times[]) {
+                float nightTime = timeDiff(times[4], times[1]); // sunset to sunrise
+                // Adjust Fajr
+                float FajrDiff = nightPortion(calculationMethod.getFajrAngle()) * nightTime;
+
+                if (isnan(times[0]) || timeDiff(times[0], times[1]) > FajrDiff)
+                        times[0] = times[1] - FajrDiff;
+
+                // Adjust Isha
+                float IshaAngle = (calculationMethod.getIshaSelector() == 0) ? calculationMethod.getIshaParam(): 18;
+                float IshaDiff = nightPortion(IshaAngle) * nightTime;
+                if (isnan(times[6]) || timeDiff(times[4], times[6]) > IshaDiff)
+                        times[6] = times[4] + IshaDiff;
+
+                // Adjust Maghrib
+                float MaghribAngle = (calculationMethod.getMaghribSelector() == 0) ? calculationMethod.getIshaParam(): 4;
+                float MaghribDiff = nightPortion(MaghribAngle) * nightTime;
+                //		if (isNaN(times[5]) || timeDiff(times[4], times[5]) > MaghribDiff)
+                if (isnan(times[5]) || timeDiff(times[4], times[5]) > MaghribDiff)
+                        times[5] = times[4] + MaghribDiff;
+
+                for (int i = 0; i < 7; i++){
+                        resultArray[i] = times[i];
+                }
+        }
+
         // adjust times in a prayer time array
         void PrayTime::adjustTimes(float * array) {
                 float *times = array;
@@ -388,9 +350,14 @@ float PrayTime::calcJD(int year, int month, int day) {
                         times[5] = times[4] + calculationMethod.getMaghribParam() / 60;
                 if (calculationMethod.getIshaSelector() == 1) // Isha
                         times[6] = times[5] + calculationMethod.getIshaParam() / 60;
-                for (int i = 0; i < 7; i++){
-                        resultArray[i] = times[i];
-                }
+                if (adjustHighLats != none){
+                                adjustHighLatTimes(times);
+                            } else {
+
+                                for (int i = 0; i < 7; i++){
+                                        resultArray[i] = times[i];
+                                }
+                            }
         }
 
         // convert times array to given time format
@@ -422,42 +389,16 @@ float PrayTime::calcJD(int year, int month, int day) {
                 adjustTimesFormat(resultArray);
         }
 
-        // adjust Fajr, Isha and Maghrib for locations in higher latitudes
-        float * PrayTime::adjustHighLatTimes(float times[]) {
-                float nightTime = timeDiff(times[4], times[1]); // sunset to sunrise
-
-                // Adjust Fajr
-                float FajrDiff = nightPortion(calculationMethod.getFajrAngle()) * nightTime;
-                if (timeDiff(times[0], times[1]) > FajrDiff)
-                        times[0] = times[1] - FajrDiff;
-
-                // Adjust Isha
-                float IshaAngle = (calculationMethod.getIshaSelector() == 0) ? calculationMethod.getIshaParam(): 18;
-                float IshaDiff = nightPortion(IshaAngle) * nightTime;
-
-                if (timeDiff(times[4], times[6]) > IshaDiff)
-                        times[6] = times[4] + IshaDiff;
-
-                // Adjust Maghrib
-                float MaghribAngle = (calculationMethod.getMaghribSelector() == 0) ? calculationMethod.getIshaParam(): 4;
-                float MaghribDiff = nightPortion(MaghribAngle) * nightTime;
-                //		if (isNaN(times[5]) || timeDiff(times[4], times[5]) > MaghribDiff)
-                if (timeDiff(times[4], times[5]) > MaghribDiff)
-                        times[5] = times[4] + MaghribDiff;
-
-                return times;
-        }
-
         // the night portion used for adjusting times in higher latitudes
         float PrayTime::nightPortion(float angle) {
             if (adjustHighLats == angleBased){
-                        return 1 / 60 * angle;
+                        return 1.0 / 60.0 * angle;
                     }
                 if (adjustHighLats == midNight){
-                        return 1 / 2;
+                        return 1.0 / 2.0;
                     }
                 if (adjustHighLats == oneSeventh){
-                        return 1 / 7;
+                        return 1.0 / 7.0;
                     }
         }
 
@@ -479,12 +420,11 @@ float PrayTime::calcJD(int year, int month, int day) {
         // return prayer times for a given date
         void PrayTime::getDatePrayerTimes(int year, int month, int day, float latitude,
                         float longitude, float tZ) {
-                float jd;
-                jd = calcJD(year, month, day);
-                //Date currentDate;
+                int jd;
+                QDate date(year, month, day);
+                jd = date.toJulianDay();
                 lat = latitude;
                 lng = longitude;
-                //timeZone = currentDate.getTimeZone();
                 timeZone = tZ;
                 jDate = jd - longitude / (15 * 24);
                 computeDayTimes();
