@@ -9,6 +9,9 @@
 #include <QLineEdit>
 #include <QRadioButton>
 #include "prayertimesettings.h"
+#include "QGeoPositionInfoSource"
+
+QTM_USE_NAMESPACE
 
 namespace Ui {
     class OptionsDialog;
@@ -22,6 +25,8 @@ public:
 
 public slots:
     void saveClickedHandler();
+    void autoConfigureClickHandler();
+    void positionUpdated(const QGeoPositionInfo &info);
 
 protected:
     void changeEvent(QEvent *e);
@@ -31,6 +36,7 @@ private:
     QString doubleToString(double in);
     QString intToString(int in);
 
+
 private:
     Ui::OptionsDialog *ui;
 #ifdef Q_OS_SYMBIAN
@@ -40,6 +46,8 @@ private:
 #endif
 
     PrayerTimeSettings settings;
+    QGeoPositionInfoSource *source;
+
 
 };
 
