@@ -1,14 +1,6 @@
 #include <QtGui/QApplication>
 #include <QFont>
-#include <QFile>
-#include <QTextStream>
 #include "mainwindow.h"
-#include <QPushButton>
-#include <stdio.h>
-#include <qstring.h>
-#include <iostream>
-#include <QtXml/QDomDocument>
-
 
 int main(int argc, char *argv[])
 {
